<?php
/*
 /////////////////// DISCLAIMER ///////////////////////////
 THIS EXAMPLE CODE IS PROVIDED TO YOU ONLY ON AN "AS IS"
 BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
 ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT,
 MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 PAYPAL MAKES NO WARRANTY THAT THE SOFTWARE OR
 DOCUMENTATION WILL BE ERROR-FREE. IN NO EVENT SHALL THE
 COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ////////////////////////////////////////////////////////////
 */


//https://developer.paypal.com/docs/limited-release/reference-transactions/#use-a-reference-transaction-to-make-a-payment

//Print all errors
error_reporting(E_ALL);
ini_set("display_errors", 1);

//Start the PHP session
session_start();

//Get the access token from the session data
$accessToken = $_SESSION['accessToken'];

//Initalise CURL
$ch = curl_init();

//Set the url endpoint
$url = 'https://api.sandbox.paypal.com/v1/payments/payment';
curl_setopt($ch, CURLOPT_URL, $url);

curl_setopt($ch, CURLOPT_SSLVERSION, CURL_SSLVERSION_TLSv1_2);

//Should to be set to true for security
curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
//Should be set to 2 for security
curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);

//Keep connection open until we get data back
curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);

//Lets curl know we are using 'post' and not 'get' (false = 'get')
curl_setopt($ch, CURLOPT_POST, TRUE);

//Set the required headers
$headers = array(
    'Accept: application/json',
    'Content-Type: application/json',
    "Authorization: Bearer $accessToken"
);
curl_setopt($ch,CURLOPT_HTTPHEADER,$headers);

//Reset the array
$vars = [];

//specify if you want to capture the funds immediatly or authorise and capture later
$vars['intent'] = 'sale';

//Specify the billing agreement token
$billing['billing_agreement_id'] = $_SESSION['billingAgreementId'];

//Specify the payment method
$fundingInstruments['billing'] = $billing;
$payer['payment_method'] = 'PAYPAL';
$payer['funding_instruments'] = array($fundingInstruments);
$vars['payer'] = $payer;

//Specify the first items details
$item1['sku'] = 'skuitemNo1';
$item1['name'] = 'ItemNo1';
$item1['description'] = 'The item description.';
$item1['quantity'] = '1';
$item1['price'] = '1.00';
$item1['currency'] = 'GBP';
$item1['tax'] = '0';
$item1['url'] = 'https://example.com/';

//Specify the second items details
$item2['sku'] = 'skuitemNo2';
$item2['name'] = 'ItemNo2';
$item2['description'] = 'The item description.';
$item2['quantity'] = '1';
$item2['price'] = '1.00';
$item2['currency'] = 'GBP';
$item2['tax'] = '0';
$item2['url'] = 'https://example.com/';

//Put the items into an array
$items = array($item1,$item2);
$itemList['items'] = $items;

//Specify the total for the transaction
$amount['currency'] = 'GBP';
$amount['total'] = '2.00';

//Specify the transaction information (NOTE: invoice must be unique for each transaction)
$transInfo['amount'] = $amount;
$transInfo['description'] = 'Payment transaction.';
$transInfo['custom'] = 'Payment custom field.';
$transInfo['note_to_payee'] = 'Note to payee field.';
//$transInfo['invoice_number'] = 'GDAGDS5754YEJ';
$transInfo['item_list'] = $itemList;

$transactions = array($transInfo);

$vars['transactions'] = $transactions;

$redirectURLs['return_url'] = 'https://example.com/return';
$redirectURLs['return_url'] = 'https://example.com/cancel';
$vars['redirect_urls'] = $redirectURLs;

//Build and set the json request
$json = json_encode($vars);
curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

//Print the request
// echo $json;

//Get the response back
$response = curl_exec($ch);

//Parse the response into an array
$outArray = json_decode($response, true);

//Print the response
echo "<pre>";
print_r($outArray);
echo "</pre>";

//Close the connection
curl_close($ch);

//Verify that the plan was created successfully
if(isset($outArray['id']))
{
    //Put the Billing Agreement Id in the session for later use
    $_SESSION['paymentId'] = $outArray['id'];
    
    echo 'Start again by clicking the button below';
    echo '<br><br>';
    echo"<a href='http://localhost/Sample_REST_RT/index.php'>return to start</a>";
}
else
{
    echo 'Sorry cannot create plan, please return to the start and try again';
    echo '<br><br>';
    echo"<a href='http://localhost/Sample_REST_RT/index.php'>return to start</a>";
}





